summaryrefslogtreecommitdiffstats
path: root/libkdepim/qutf7codec.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/qutf7codec.h')
-rw-r--r--libkdepim/qutf7codec.h30
1 files changed, 14 insertions, 16 deletions
diff --git a/libkdepim/qutf7codec.h b/libkdepim/qutf7codec.h
index 116fa02a..6bb5117e 100644
--- a/libkdepim/qutf7codec.h
+++ b/libkdepim/qutf7codec.h
@@ -15,23 +15,21 @@
02110-1301, US
As a special exception, permission is granted to use this plugin
- with any version of Qt by TrollTech AS, Norway. In this case, the
+ with any version of TQt by TrollTech AS, Norway. In this case, the
use of this plugin doesn't cause the resulting executable to be
covered by the GNU General Public License.
This exception does not however tqinvalidate any other reasons why the
executable file might be covered by the GNU General Public License.
*/
-#ifndef QUTF7CODEC_H
-#define QUTF7CODEC_H
+#ifndef TQUTF7CODEC_H
+#define TQUTF7CODEC_H
-#ifndef QT_H
#include "tqtextcodec.h"
-#endif
#include <kdepimmacros.h>
-#ifndef QT_NO_TEXTCODEC
+#ifndef TQT_NO_TEXTCODEC
/** @short A TQTextCodec for the UTF-7 transformation of Unicode.
@@ -47,10 +45,10 @@
@author Marc Mutz <mutz@kde.org> */
-class KDE_EXPORT QUtf7Codec : public TQTextCodec {
+class KDE_EXPORT TQUtf7Codec : public TQTextCodec {
bool encOpt, encLwsp;
public:
- QUtf7Codec() : TQTextCodec() {}
+ TQUtf7Codec() : TQTextCodec() {}
int mibEnum() const;
const char* name() const;
@@ -65,14 +63,14 @@ public:
int heuristicContentMatch( const char* chars, int len ) const;
};
-/** This is a version of @ref QUtf7Codec, which should only be used in
- MIME transfer. It differs from @ref QUtf7Codec only in that the
+/** This is a version of @ref TQUtf7Codec, which should only be used in
+ MIME transfer. It differs from @ref TQUtf7Codec only in that the
encoder escapes additional characters (the RFC2152 "optional
direct set"), which might not be allowed in RFC822/RFC2047 header
fields.
You should only use this codec for @em encoding, since it's output
- is pure UTF-7 and can equally well be decoded by @ref QUtf7Codec's
+ is pure UTF-7 and can equally well be decoded by @ref TQUtf7Codec's
decoder.
To distinguish between the two variants, this class has MIB enum
@@ -80,12 +78,12 @@ public:
"X-QT-UTF-7-STRICT". The MIME preferred charset name is still
"UTF-7", though.
- @short A variant of @ref QUtf7Codec, which protectes certain
+ @short A variant of @ref TQUtf7Codec, which protectes certain
characters in MIME transport
@author Marc Mutz <mutz@kde.org> */
-class KDE_EXPORT QStrictUtf7Codec : public QUtf7Codec {
+class KDE_EXPORT TQStrictUtf7Codec : public TQUtf7Codec {
public:
- QStrictUtf7Codec() : QUtf7Codec() {}
+ TQStrictUtf7Codec() : TQUtf7Codec() {}
const char* name() const;
int mibEnum() const;
@@ -93,6 +91,6 @@ public:
TQTextEncoder* makeEncoder() const;
};
-#endif // QT_NO_TEXTCODEC
+#endif // TQT_NO_TEXTCODEC
-#endif // QUTF7CODEC_H
+#endif // TQUTF7CODEC_H